Replay protection storage keys
Structs
- Key
- A storage key is made of storage key segments
DbKeySeg, separated byKEY_SEGMENT_SEPARATOR.
Functions
- commitment_
key - Get the key under which we store a hash which is commitment to all replay protection entries.
- current_
key - Get the transaction hash key under the
currentsubkey - current_
prefix - Get the transaction hash prefix under the
currentsubkey - key
- Get the transaction hash key